# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.5.1] - 2023-04-19 14:12:33

### Fixed

- API deployment action.

## [0.5.0] - 2023-04-19 13:01:35

### Added

- Parameter metadata for all parameters.

### Fixed

- MTR calculation bugs.

## [0.4.2] - 2023-03-25 14:38:37

### Fixed

- Data syntax updated for new Core version.

## [0.4.1] - 2023-02-12 03:34:30

### Added

- Tax integration test.

## [0.4.0] - 2023-02-11 14:44:00

### Added

- Formula for marginal_tax_rate.

## [0.3.0] - 2023-02-11 13:43:36

### Added

- Personal income tax logic.

## [0.2.0] - 2023-02-11 13:23:04

### Added

- Live site requirements.

## [0.1.0] - 2023-02-11 12:49:53

### Added

- Consolidated relief allowance.

## [0.0.2] - 2023-02-10 01:54:05

### Fixed

- Entity bugs.

## [0.0.1] - 2023-02-09 00:00:00

### Added

- Initial Nigeria template.



[0.5.1]: https://github.com/PolicyEngine/policyengine-ng/compare/0.5.0...0.5.1
[0.5.0]: https://github.com/PolicyEngine/policyengine-ng/compare/0.4.2...0.5.0
[0.4.2]: https://github.com/PolicyEngine/policyengine-ng/compare/0.4.1...0.4.2
[0.4.1]: https://github.com/PolicyEngine/policyengine-ng/compare/0.4.0...0.4.1
[0.4.0]: https://github.com/PolicyEngine/policyengine-ng/compare/0.3.0...0.4.0
[0.3.0]: https://github.com/PolicyEngine/policyengine-ng/compare/0.2.0...0.3.0
[0.2.0]: https://github.com/PolicyEngine/policyengine-ng/compare/0.1.0...0.2.0
[0.1.0]: https://github.com/PolicyEngine/policyengine-ng/compare/0.0.2...0.1.0
[0.0.2]: https://github.com/PolicyEngine/policyengine-ng/compare/0.0.1...0.0.2

